@@ -58,6 +58,12 @@ public:
 
   virtual void set_modified(bool value = true);
 
+  /** Set the file URI that will be used in future calls to load() and save().
+   * Note that the document will not be saved immediately to the new URI. It will
+   * be saved either after the next change (if using autosave) or when calling save() explicitly.
+   * Likewise, the document at the URI will not be loaded until load() is called explicitly.
+   * That is unlike in the base class's implementation.
+   */
   virtual void set_file_uri(const Glib::ustring& file_uri, bool bEnforceFileExtension = false);
 
   /* Loads data from disk, using the URI (set with set_file_uri()) then asks the View to update itself.
@@ -168,6 +174,11 @@ public:
    */
   Glib::ustring get_translation_original_locale() const;
 
+  /** Get a list of locales for which at least one string is translated.
+   * The result will include the original, from get_translation_original_locale().
+   */
+  std::vector<Glib::ustring> get_translation_available_locales() const;
+
   typedef std::vector< sharedptr<Relationship> > type_vec_relationships;
   type_vec_relationships get_relationships(const Glib::ustring& table_name, bool plus_system_prefs = false) const;
   void set_relationships(const Glib::ustring& table_name, const type_vec_relationships& vecRelationships);
@@ -199,6 +210,16 @@ public:
    * so that it is not used anymore in relationships, layouts, reports, etc.
    */
   void remove_field(const Glib::ustring& table_name, const Glib::ustring& field_name);
+  
+  
+  typedef std::pair< sharedptr<LayoutItem_Field>, sharedptr<Relationship> > type_pairFieldTrigger;
+  typedef std::list<type_pairFieldTrigger> type_list_lookups;
+  
+  /** Get the fields whose values should be looked up when @a field_name changes, with
+   * the relationship used to lookup the value.
+   */
+  type_list_lookups get_lookup_fields(const Glib::ustring& table_name, const Glib::ustring& field_name) const;
+
 
 
   typedef std::vector< sharedptr<LayoutGroup> > type_list_layout_groups;
@@ -243,8 +264,6 @@ public:
   void fill_layout_field_details(const Glib::ustring& parent_table_name, const sharedptr<LayoutGroup>& layout_group) const;
   void fill_layout_field_details(const Glib::ustring& parent_table_name, type_list_layout_groups& groups) const;
 
-
-
   ///When a field name is changed, change it in the relationships, layouts, reports, and fields data:
   void change_field_name(const Glib::ustring& table_name, const Glib::ustring& strFieldNameOld, const Glib::ustring& strFieldNameNew);
 
@@ -497,6 +516,8 @@ private:
 
   void fill_translatable_layout_items(const sharedptr<LayoutGroup>& group, type_list_translatables& the_list);
 
+  void fill_sort_field_details(const Glib::ustring& parent_table_name, FieldFormatting::type_list_sort_fields& sort_fields) const;
+
 
   /// If the attribute is not there, then the default will be returned.
   static bool get_node_attribute_value_as_bool(const xmlpp::Element* node, const Glib::ustring& strAttributeName, bool value_default = false);
@@ -620,6 +641,7 @@ private:
 
   Glib::ustring m_database_title;
   Glib::ustring m_translation_original_locale;
+  std::vector<Glib::ustring> m_translation_available_locales; //Just a cache, based on other data.
 
   typedef std::map<Glib::ustring, Glib::ustring> type_map_library_scripts;
   type_map_library_scripts m_map_library_scripts;
