@@ -45,8 +45,6 @@
 
 #include <stack>
 
-#include <fcntl.h> //For close(). This include is needed in mingw on MS Windows.
-
 namespace Glom
 {
 
@@ -555,8 +553,9 @@ Utils::type_list_values_with_second Utils::get_choice_values(const Document* doc
   sharedptr<const Relationship> choice_relationship;
   sharedptr<const LayoutItem_Field> layout_choice_first;
   sharedptr<const LayoutGroup> layout_choice_extra;
+  FieldFormatting::type_list_sort_fields choice_sort_fields;
   bool choice_show_all = false;
-  format.get_choices_related(choice_relationship, layout_choice_first, layout_choice_extra, choice_show_all);
+  format.get_choices_related(choice_relationship, layout_choice_first, layout_choice_extra, choice_sort_fields, choice_show_all);
 
   if(!choice_relationship)
   {
@@ -588,8 +587,11 @@ Utils::type_list_values_with_second Utils::get_choice_values(const Document* doc
     std::cerr << G_STRFUNC << ": to_field is null." << std::endl;
   }
 
-  type_sort_clause sort_clause;
-  sort_clause.push_back( type_pair_sort_field(layout_choice_first, true /* ascending */));
+  //Default to some sort order rather than none:
+  if(choice_sort_fields.empty())
+  {
+    choice_sort_fields.push_back( type_pair_sort_field(layout_choice_first, true /* ascending */));
+  }
 
   //TODO: Support related relationships (in the UI too):
   Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Utils::build_sql_select_with_key(
@@ -597,7 +599,7 @@ Utils::type_list_values_with_second Utils::get_choice_values(const Document* doc
     fields,
     to_field,
     foreign_key_value,
-    sort_clause);
+    choice_sort_fields);
 
   if(!builder)
   {
@@ -728,16 +730,15 @@ Glib::ustring Utils::locale_simplify(const Glib::ustring& locale_id)
 
 Glib::ustring Utils::locale_language_id(const Glib::ustring& locale_id)
 {
+  Glib::ustring result;
+
   const Glib::ustring::size_type posUnderscore = locale_id.find('_');
   if(posUnderscore != Glib::ustring::npos)
   {
-    return locale_id.substr(0, posUnderscore);
-  }
-  else
-  {
-    //We assume that this locale ID specifies a language but no specific country.
-    return locale_id;
+    result = locale_id.substr(0, posUnderscore);
   }
+
+  return result;
 }
 
 Glib::ustring Utils::create_local_image_uri(const Gnome::Gda::Value& value)
@@ -1099,15 +1100,6 @@ std::string Utils::sqlbuilder_get_full_query(
 
 Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const Document* document, const Glib::ustring& table_name, const Gnome::Gda::Value& quick_search)
 {
-  if(table_name.empty())
-  {
-    std::cerr << G_STRFUNC << ": table_name is empty." << std::endl;
-    return Gnome::Gda::SqlExpr();
-  }
-
-  if(Conversions::value_is_empty(quick_search))
-    return Gnome::Gda::SqlExpr();
-  
   Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
     Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_target(table_name);
@@ -1363,6 +1355,25 @@ Glib::ustring Utils::get_list_of_layout_items_for_display(const sharedptr<const
     return Glib::ustring();
 }
 
+Glib::ustring Utils::get_list_of_sort_fields_for_display(const FieldFormatting::type_list_sort_fields& sort_fields)
+{
+  Glib::ustring text;
+  for(FieldFormatting::type_list_sort_fields::const_iterator iter = sort_fields.begin(); iter != sort_fields.end(); ++iter)
+  {
+    const sharedptr<const LayoutItem_Field> item = iter->first;
+    if(!item)
+      continue;
+    
+    if(!text.empty())
+      text += ", ";
+
+    text += item->get_layout_display_name();
+    //TODO: Show Ascending/Descending?
+  }
+
+  return text;
+}
+
 std::string Utils::get_temp_file_path(const std::string& prefix, const std::string& extension)
 {
   //Get a temporary file path:
@@ -1432,72 +1443,5 @@ Glib::ustring Utils::get_temp_directory_uri(const std::string& prefix)
   }
 }
 
-LayoutGroup::type_list_const_items Utils::get_layout_items_plus_primary_key(const LayoutGroup::type_list_const_items& items, const Document* document, const Glib::ustring& table_name)
-{
-  if(!document)
-  {
-    std::cerr << G_STRFUNC << ": document was null." << std::endl;
-    return items;
-  }
-
-  const sharedptr<Field> field_primary_key = document->get_field_primary_key(table_name);
-  if(!field_primary_key)
-  {
-    std::cerr << G_STRFUNC << ": Could not find the primary key." << std::endl;
-    return items;
-  }
-
-  sharedptr<LayoutItem_Field> pk_layout_item = sharedptr<LayoutItem_Field>::create();
-  pk_layout_item->set_hidden();
-  pk_layout_item->set_full_field_details(field_primary_key);
-  
-  const LayoutGroup::type_list_const_items::const_iterator iterFind = std::find_if(items.begin(), items.end(), predicate_LayoutItem_Field_IsSameField<LayoutItem_Field, LayoutItem>(pk_layout_item));
-  if(iterFind != items.end())
-    return items; //It is already in the list:
-
-  LayoutGroup::type_list_const_items items_plus_pk = items;
-  items_plus_pk.push_back(pk_layout_item);
-  return items_plus_pk;
-}
-
-//TODO: Avoid the horrible code duplication with the const version.
-LayoutGroup::type_list_items Utils::get_layout_items_plus_primary_key(const LayoutGroup::type_list_items& items, const Document* document, const Glib::ustring& table_name)
-{
-  if(!document)
-  {
-    std::cerr << G_STRFUNC << ": document was null." << std::endl;
-    return items;
-  }
-
-  const sharedptr<Field> field_primary_key = document->get_field_primary_key(table_name);
-  if(!field_primary_key)
-  {
-    std::cerr << G_STRFUNC << ": Could not find the primary key." << std::endl;
-    return items;
-  }
-
-  sharedptr<LayoutItem_Field> pk_layout_item = sharedptr<LayoutItem_Field>::create();
-  pk_layout_item->set_hidden();
-  pk_layout_item->set_full_field_details(field_primary_key);
-  
-  const LayoutGroup::type_list_items::const_iterator iterFind = std::find_if(items.begin(), items.end(), predicate_LayoutItem_Field_IsSameField<LayoutItem_Field, LayoutItem>(pk_layout_item));
-  if(iterFind != items.end())
-    return items; //It is already in the list:
-
-  LayoutGroup::type_list_items items_plus_pk = items;
-  items_plus_pk.push_back(pk_layout_item);
-  return items_plus_pk;
-}
-
-bool Utils::script_check_for_pygtk2(const Glib::ustring& script)
-{
-  //There are probably other code that this will not catch,
-  //but this is better than nothing.
-  //TODO: Instead override python's import mechanism somehow?
-  if(script.find("import pygtk") != std::string::npos)
-    return false;
-
-  return true;
-}
 
 } //namespace Glom
