@@ -121,7 +121,7 @@ void ComboChoicesWithTreeModel::delete_model()
   m_refModel.reset();
 }
 
-/*
+/* TODO: Remove this
 void ComboChoicesWithTreeModel::set_choices_with_second(const type_list_values_with_second& list_values)
 {
   //Recreate the entire model:
@@ -246,15 +246,15 @@ void ComboChoicesWithTreeModel::set_choices_related(const Document* document, co
   sharedptr<const Relationship> choice_relationship;
   sharedptr<const LayoutItem_Field> layout_choice_first;
   sharedptr<const LayoutGroup> layout_choice_extra;
+  FieldFormatting::type_list_sort_fields choice_sort_fields;
   bool choice_show_all = false;
-  format.get_choices_related(choice_relationship, layout_choice_first, layout_choice_extra, choice_show_all);
+  format.get_choices_related(choice_relationship, layout_choice_first, layout_choice_extra, choice_sort_fields, choice_show_all);
   if(layout_choice_first->get_glom_type() == Field::TYPE_INVALID)
     std::cerr << G_STRFUNC << ": layout_choice_first has invalid type. field name: " << layout_choice_first->get_name() << std::endl;
 
   //Set full field details, cloning the group to avoid the constness:
   sharedptr<LayoutGroup> layout_choice_extra_full = glom_sharedptr_clone(layout_choice_extra);
-  const Glib::ustring table_name = choice_relationship->get_to_table();
-  document->fill_layout_field_details(table_name,  layout_choice_extra_full);
+  document->fill_layout_field_details(choice_relationship->get_to_table(), layout_choice_extra_full);
 
   //Get the list of fields to show:
   LayoutGroup::type_list_items extra_fields;
@@ -265,10 +265,6 @@ void ComboChoicesWithTreeModel::set_choices_related(const Document* document, co
   layout_items.push_back(layout_choice_first);
   layout_items.insert(layout_items.end(), extra_fields.begin(), extra_fields.end());
 
-  //Make sure that the primary key is also in the list, but hidden,
-  //because TreeModel_DB needs it:
-  layout_items = Utils::get_layout_items_plus_primary_key(layout_items, document, table_name);
-
   //Build the FoundSet:
   const Glib::ustring to_table = choice_relationship->get_to_table();
   FoundSet found_set;
@@ -282,10 +278,12 @@ void ComboChoicesWithTreeModel::set_choices_related(const Document* document, co
       to_table, to_field, foreign_key_value);
   }
 
-  //Sort by the first field, because that is better than so sort at all.
-  //TODO: Allow the developer to specify the sort order:
-  found_set.m_sort_clause.push_back( FoundSet::type_pair_sort_field(layout_choice_first, true /* ascending */) );
-
+  found_set.m_sort_clause = choice_sort_fields;
+  if(found_set.m_sort_clause.empty())
+  {
+    //Sort by the first field, because that is better than so sort at all.
+    found_set.m_sort_clause.push_back( FoundSet::type_pair_sort_field(layout_choice_first, true /* ascending */) );
+  }
 
   m_db_layout_items.clear();
 
@@ -306,73 +304,6 @@ Glib::RefPtr<Gtk::TreeModel> ComboChoicesWithTreeModel::get_choices_model()
   return m_refModel;
 }
 
-void ComboChoicesWithTreeModel::set_cell_for_field_value(Gtk::CellRenderer* cell, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
-{
-  if(!field)
-    return;
-
-  if(!cell)
-    return;
-
-  const Field::glom_field_type type = field->get_glom_type();
-  switch(type)
-  {
-    case(Field::TYPE_BOOLEAN):
-    {
-      Gtk::CellRendererToggle* pDerived = dynamic_cast<Gtk::CellRendererToggle*>(cell);
-      if(pDerived)
-        pDerived->set_active( (value.get_value_type() == G_TYPE_BOOLEAN) && value.get_boolean() );
-
-      break;
-    }
-    case(Field::TYPE_IMAGE):
-    {
-      Gtk::CellRendererPixbuf* pDerived = dynamic_cast<Gtk::CellRendererPixbuf*>(cell);
-      if(pDerived)
-      {
-        const Glib::RefPtr<Gdk::Pixbuf> pixbuf = Utils::get_pixbuf_for_gda_value(value);
-
-        //Scale it down to a sensible size.
-        //TODO: if(pixbuf)
-        //  pixbuf = Utils::image_scale_keeping_ratio(pixbuf,  get_fixed_cell_height(), pixbuf->get_width());
-        g_object_set(pDerived->gobj(), "pixbuf", pixbuf ? pixbuf->gobj() : 0, (gpointer)0);
-      }
-      else
-        std::cerr << "Field::sql(): glom_type is TYPE_IMAGE but gda type is not VALUE_TYPE_BINARY" << std::endl;
-
-      break;
-    }
-    default:
-    {
-      //TODO: Maybe we should have custom cellcells for time, date, and numbers.
-      Gtk::CellRendererText* pDerived = dynamic_cast<Gtk::CellRendererText*>(cell);
-      if(pDerived)
-      {
-        //std::cout << "debug: " << G_STRFUNC << ": field name=" << field->get_name() << ", glom type=" << field->get_glom_type() << std::endl;
-        const Glib::ustring text = Conversions::get_text_for_gda_value(field->get_glom_type(), value, field->get_formatting_used().m_numeric_format);
-        pDerived->property_text() = text;
-      }
-      else
-      {
-         std::cerr << G_STRFUNC << ": cell has an unexpected type: " << typeid(cell).name() << std::endl;
-      }
-
-      //Show a different color if the value is numeric, if that's specified:
-      if(type == Field::TYPE_NUMERIC)
-      {
-        const Glib::ustring fg_color =
-        field->get_formatting_used().get_text_format_color_foreground_to_use(value);
-        if(!fg_color.empty())
-          g_object_set(pDerived->gobj(), "foreground", fg_color.c_str(), (gpointer)0);
-        else
-          g_object_set(pDerived->gobj(), "foreground", (const char*)0, (gpointer)0);
-      }
-
-      break;
-    }
-  }
-}
-
 void ComboChoicesWithTreeModel::on_cell_data(const Gtk::TreeModel::iterator& iter, Gtk::CellRenderer* cell, guint model_column_index)
 {
   //std::cout << G_STRFUNC << ": DEBUG: model_column_index=" << model_column_index << std::endl;
@@ -388,19 +319,76 @@ void ComboChoicesWithTreeModel::on_cell_data(const Gtk::TreeModel::iterator& ite
     return;
   }
 
-  if(!iter)
-    return;
+  if(iter)
+  {
+    const sharedptr<const LayoutItem>& layout_item = m_db_layout_items[model_column_index];
 
-  const sharedptr<const LayoutItem>& layout_item = m_db_layout_items[model_column_index];
-  sharedptr<const LayoutItem_Field> field = sharedptr<const LayoutItem_Field>::cast_dynamic(layout_item);
-  if(!field)
-    return;
+    sharedptr<const LayoutItem_Field> field = sharedptr<const LayoutItem_Field>::cast_dynamic(layout_item);
+    if(field)
+    {
+      Gtk::TreeModel::Row treerow = *iter;
+      Gnome::Gda::Value value;
+      treerow->get_value(model_column_index, value);
 
-  Gnome::Gda::Value value;
-  Gtk::TreeModel::Row treerow = *iter;
-  treerow->get_value(model_column_index, value);
+      const Field::glom_field_type type = field->get_glom_type();
+      switch(type)
+      {
+        case(Field::TYPE_BOOLEAN):
+        {
+          Gtk::CellRendererToggle* pDerived = dynamic_cast<Gtk::CellRendererToggle*>(cell);
+          if(pDerived)
+            pDerived->set_active( (value.get_value_type() == G_TYPE_BOOLEAN) && value.get_boolean() );
 
-  set_cell_for_field_value(cell, field, value);
+          break;
+        }
+        case(Field::TYPE_IMAGE):
+        {
+          Gtk::CellRendererPixbuf* pDerived = dynamic_cast<Gtk::CellRendererPixbuf*>(cell);
+          if(pDerived)
+          {
+            const Glib::RefPtr<Gdk::Pixbuf> pixbuf = Utils::get_pixbuf_for_gda_value(value);
+
+            //Scale it down to a sensible size.
+            //TODO: if(pixbuf)
+            //  pixbuf = Utils::image_scale_keeping_ratio(pixbuf,  get_fixed_cell_height(), pixbuf->get_width());
+            g_object_set(pDerived->gobj(), "pixbuf", pixbuf ? pixbuf->gobj() : 0, (gpointer)0);
+          }
+          else
+            std::cerr << "Field::sql(): glom_type is TYPE_IMAGE but gda type is not VALUE_TYPE_BINARY" << std::endl;
+
+          break;
+        }
+        default:
+        {
+          //TODO: Maybe we should have custom cellcells for time, date, and numbers.
+          Gtk::CellRendererText* pDerived = dynamic_cast<Gtk::CellRendererText*>(cell);
+          if(pDerived)
+          {
+            //std::cout << "debug: " << G_STRFUNC << ": field name=" << field->get_name() << ", glom type=" << field->get_glom_type() << std::endl;
+            const Glib::ustring text = Conversions::get_text_for_gda_value(field->get_glom_type(), value, field->get_formatting_used().m_numeric_format);
+            pDerived->property_text() = text;
+          }
+          else
+          {
+             std::cerr << G_STRFUNC << ": cell has an unexpected type: " << typeid(cell).name() << std::endl;
+          }
+
+          //Show a different color if the value is numeric, if that's specified:
+          if(type == Field::TYPE_NUMERIC)
+          {
+             const Glib::ustring fg_color =
+               field->get_formatting_used().get_text_format_color_foreground_to_use(value);
+             if(!fg_color.empty())
+                 g_object_set(pDerived->gobj(), "foreground", fg_color.c_str(), (gpointer)0);
+             else
+                 g_object_set(pDerived->gobj(), "foreground", (const char*)0, (gpointer)0);
+          }
+
+          break;
+        }
+      }
+    }
+  }
 }
 
 void ComboChoicesWithTreeModel::cell_connect_cell_data_func(Gtk::CellLayout* celllayout, Gtk::CellRenderer* cell, guint model_column_index)
