@@ -76,18 +76,19 @@ Window_Translations::Window_Translations(BaseObjectType* cobject, const Glib::Re
     column_original->pack_start(*renderer_name);
     column_original->set_cell_data_func(*renderer_name, sigc::mem_fun(*this, &Window_Translations::on_cell_data_original));
 
-    const int col = m_treeview->append_column_editable(_("Translation"), m_columns.m_col_translation);
-    Gtk::CellRendererText* renderer = dynamic_cast<Gtk::CellRendererText*>(m_treeview->get_column_cell_renderer(col - 1));
-    if(renderer)
-      renderer->signal_edited().connect(sigc::mem_fun(*this, &Window_Translations::on_treeview_edited));
 
-    //This is at the end, because it can contain a long description of the item's context.
     Gtk::TreeView::Column* column_item_typename = Gtk::manage( new Gtk::TreeView::Column(_("Item")) );
     m_treeview->append_column(*column_item_typename);
 
     Gtk::CellRendererText* renderer_item_typename = Gtk::manage(new Gtk::CellRendererText);
     column_item_typename->pack_start(*renderer_item_typename);
     column_item_typename->set_cell_data_func(*renderer_item_typename, sigc::mem_fun(*this, &Window_Translations::on_cell_data_item_typename));
+
+
+    const int col = m_treeview->append_column_editable(_("Translation"), m_columns.m_col_translation);
+    Gtk::CellRendererText* renderer = dynamic_cast<Gtk::CellRendererText*>(m_treeview->get_column_cell_renderer(col - 1));
+    if(renderer)
+      renderer->signal_edited().connect(sigc::mem_fun(*this, &Window_Translations::on_treeview_edited));
   }
 
   builder->get_widget("button_identify", m_button_identify);
@@ -120,11 +121,6 @@ Window_Translations::Window_Translations(BaseObjectType* cobject, const Glib::Re
     m_combo_target_locale->set_selected_locale(m_translation_locale);
     //The translations will be shown in the treeview when load_from_document() is called.
   }
-  else
-  {
-    //Start with _some_ locale, rather than no locale:
-    m_combo_target_locale->set_active(0);
-  }
 }
 
 Window_Translations::~Window_Translations()
@@ -235,7 +231,7 @@ void Window_Translations::load_from_document()
     Gtk::TreeModel::iterator iterTree = m_model->append();
     Gtk::TreeModel::Row row = *iterTree;
     row[m_columns.m_col_item] = tableinfo;
-    row[m_columns.m_col_translation] = tableinfo->get_title(m_translation_locale);
+    row[m_columns.m_col_translation] = tableinfo->get_title_translation(m_translation_locale, false);
     row[m_columns.m_col_parent_table] = Glib::ustring(); //Not used for tables.
 
     //The table's field titles:
@@ -247,7 +243,7 @@ void Window_Translations::load_from_document()
 
       sharedptr<Field> field = *iter;
       row[m_columns.m_col_item] = field;
-      row[m_columns.m_col_translation] = field->get_title(m_translation_locale);
+      row[m_columns.m_col_translation] = field->get_title_translation(m_translation_locale, false);
       row[m_columns.m_col_parent_table] = table_name;
 
     }
@@ -263,7 +259,7 @@ void Window_Translations::load_from_document()
         Gtk::TreeModel::Row row = *iterTree;
 
         row[m_columns.m_col_item] = relationship;
-        row[m_columns.m_col_translation] = relationship->get_title(m_translation_locale);
+        row[m_columns.m_col_translation] = relationship->get_title_translation(m_translation_locale, false);
         row[m_columns.m_col_parent_table] = table_name;
       }
     }
@@ -281,7 +277,7 @@ void Window_Translations::load_from_document()
         Gtk::TreeModel::Row row = *iterTree;
 
         row[m_columns.m_col_item] = report;
-        row[m_columns.m_col_translation] = report->get_title(m_translation_locale);
+        row[m_columns.m_col_translation] = report->get_title_translation(m_translation_locale, false);
         row[m_columns.m_col_parent_table] = table_name;
 
         //Translatable report items:
@@ -297,7 +293,7 @@ void Window_Translations::load_from_document()
               Gtk::TreeModel::Row row = *iterTree;
 
               row[m_columns.m_col_item] = item;
-              row[m_columns.m_col_translation] = item->get_title(m_translation_locale);
+              row[m_columns.m_col_translation] = item->get_title_translation(m_translation_locale, false);
               row[m_columns.m_col_parent_table] = table_name;
             }
           }
@@ -318,7 +314,7 @@ void Window_Translations::load_from_document()
           Gtk::TreeModel::Row row = *iterTree;
 
           row[m_columns.m_col_item] = item;
-          row[m_columns.m_col_translation] = item->get_title(m_translation_locale);
+          row[m_columns.m_col_translation] = item->get_title_translation(m_translation_locale, false);
           row[m_columns.m_col_parent_table] = table_name;
         }
       }
@@ -344,7 +340,7 @@ void Window_Translations::save_to_document()
     if(item)
     {
       const Glib::ustring translation = row[m_columns.m_col_translation];
-      item->set_title(m_translation_locale, translation);
+      item->set_title_translation(m_translation_locale, translation);
     }
   }
 
@@ -390,7 +386,7 @@ void Window_Translations::on_button_copy_translation()
         if(item)
         {
           //Copy the translation from the chosen locale to the current locale:
-          const Glib::ustring translation = item->get_title(copy_source_locale);
+          const Glib::ustring translation = item->get_title_translation(copy_source_locale);
           row[m_columns.m_col_translation] = translation;
         }
       }
@@ -551,7 +547,7 @@ void Window_Translations::on_button_export()
         {
           po_message_t msg = po_message_create();
           po_message_set_msgid(msg, item->get_title_original().c_str());
-          po_message_set_msgstr(msg, item->get_translation(m_translation_locale).c_str());
+          po_message_set_msgstr(msg, item->get_title_translation(m_translation_locale, false).c_str());
 
           // Add "context" comments, to uniquely identify similar strings, used in different places,
           // and to provide a hint for translators.
@@ -653,7 +649,7 @@ void Window_Translations::on_button_import()
               if( (item->get_title_original() == msgid) && 
                   (get_po_context_for_item(item) == msgcontext) ) // This is not efficient, but it should be reliable.
               {
-                item->set_translation(m_translation_locale, msgstr);
+                item->set_title_translation(m_translation_locale, msgstr);
                 // Keep examining items, in case there are duplicates. break;
               }
             }
